@@ -119,6 +119,10 @@ impl Var {
             var: self.var.clone(),
         }
     }
+    /// With a &Var, use set to copy a value.
+    pub fn set(&self, o: &Var) {
+        self.var.borrow_mut().set(&o.var.borrow());
+    }
 
     pub fn size(&self) -> Vec<usize> {
         self.var.borrow().size()
@@ -139,10 +143,6 @@ impl Var {
         self.var.borrow_mut().set_f64(o, v)
     }
 
-    pub fn set(&self, o: &Var) {
-        self.var.borrow_mut().set(&o.var.borrow());
-    }
-
     pub fn fill(size: &[usize], fill_value: &Var) -> Var {
         Var {
             var: Rc::new(RefCell::new(
@@ -546,7 +546,7 @@ impl Var {
 
 
     // innternal use
-    pub(crate) fn val(&self) -> Tensor {
+    pub fn val(&self) -> Tensor {
         self.var.borrow().val()
     }
 
@@ -589,6 +589,25 @@ impl Var {
 	Ok((inputs.drain(..).map(|x| Var {var: Rc::new(RefCell::new(x))}).collect(),
 	    outputs.drain(..).map(|x| Var {var: Rc::new(RefCell::new(x))}).collect()))
     }
+    
+    /// Get var by string label
+    pub fn get_var_by_label(&self, label: &str) -> Result<Var, AutoDiffError> {
+	let inner = self.var.borrow().get_var_by_label(label)?;
+	Ok(Var {
+	    var: Rc::new(RefCell::new(inner)),
+	})
+    }
+
+    pub fn set_label(&self, label: &str) -> Result<(), AutoDiffError> {
+	self.var.borrow().set_label(label)
+    }
+
+    pub fn set_predict(&self) -> Result<(), AutoDiffError> {
+	self.set_label("__predict__")
+    }
+    pub fn predict(&self) -> Result<Var, AutoDiffError> {
+	self.get_var_by_label("__predict__")
+    }
 
     pub(crate) fn called_with(&self, op: Op,
                               others: &[&Var]) -> Result<Vec<Var>, AutoDiffError> {
@@ -690,6 +709,9 @@ impl TryFrom<Var> for f32 {
     type Error = AutoDiffError;
 
     fn try_from(value: Var) -> Result<Self, Self::Error> {
+        if value.numel() > 1 {
+            return Err(AutoDiffError::new("TryFrom<Var> for f32 only works for 1 element var."))
+        }
 	let index = vec![0; value.size().len()];
 	value.get_f32(&index)
     }
@@ -699,12 +721,27 @@ impl TryFrom<Var> for f64 {
     type Error = AutoDiffError;
 
     fn try_from(value: Var) -> Result<Self, Self::Error> {
+        if value.numel() > 1 {
+            return Err(AutoDiffError::new("TryFrom<Var> for f64 only works for 1 element var."));
+        }
 	let index = vec![0; value.size().len()];
 	value.get_f64(&index)
     }
 }
 
+impl TryFrom<Var> for Vec<usize> {
+    type Error = AutoDiffError;
 
+    fn try_from(value: Var) -> Result<Self, Self::Error> {
+        let t = value.val();
+        if t.size().len() > 2 {
+            return Err(AutoDiffError::new("expect size [n,1], or [n]."));
+        }
+        let value = t.reshape(&[value.numel()]);
+        let ret = value.get_raw_f64().iter().map(|x| *x as usize).collect();
+        Ok(ret)
+    }
+}
 
 #[macro_export]
 macro_rules! var_f64 {
